==> haskell-th-expand-syns-0.4.9.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-expand-syns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-expand-syns
version:              0.4.9.0
visibility:           public
id:                   th-expand-syns-0.4.9.0-GRD16qbA8NzJIxerLQ7Zdc
key:                  th-expand-syns-0.4.9.0-GRD16qbA8NzJIxerLQ7Zdc
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Daniel Schüssler
homepage:             https://github.com/DanielSchuessler/th-expand-syns
synopsis:             Expands type synonyms in Template Haskell ASTs
description:
    Expands type synonyms in Template Haskell ASTs.

    As of version @0.4.9.0@, this library is a small shim on
    top of the @applySubstitution@/@resolveTypeSynonyms@
    functions from @th-abstraction@, so you may want to
    consider using @th-abstraction@ instead.

category:             Template Haskell
abi:                  d5058d3c5df7abc443fd7a3dde54fdeb
exposed:              True
exposed-modules:      Language.Haskell.TH.ExpandSyns
hidden-modules:       Language.Haskell.TH.ExpandSyns.SemigroupCompat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-expand-syns-0.4.9.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-expand-syns-0.4.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/th-expand-syns-0.4.9.0
hs-libraries:         HSth-expand-syns-0.4.9.0-GRD16qbA8NzJIxerLQ7Zdc
depends:
    base-4.15.1.0 containers-0.6.4.1 syb-0.7.2.1-CMeJWgSwItuEGmFSowZSJf
    template-haskell-2.17.0.0
    th-abstraction-0.4.3.0-KTsBdnGbxBE1GYg4VOLAou

haddock-interfaces:
    /usr/share/doc/haskell-th-expand-syns/html/th-expand-syns.haddock

haddock-html:         /usr/share/doc/haskell-th-expand-syns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-expand-syns-0.4.9.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-expand-syns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-expand-syns
version:              0.4.9.0
visibility:           public
id:                   th-expand-syns-0.4.9.0-4fdSEazGb6JE84XYYt25ma
key:                  th-expand-syns-0.4.9.0-4fdSEazGb6JE84XYYt25ma
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Daniel Schüssler
homepage:             https://github.com/DanielSchuessler/th-expand-syns
synopsis:             Expands type synonyms in Template Haskell ASTs
description:
    Expands type synonyms in Template Haskell ASTs.

    As of version @0.4.9.0@, this library is a small shim on
    top of the @applySubstitution@/@resolveTypeSynonyms@
    functions from @th-abstraction@, so you may want to
    consider using @th-abstraction@ instead.

category:             Template Haskell
abi:                  bf49ecdbf782dd84e294174d71e3bb38
exposed:              True
exposed-modules:      Language.Haskell.TH.ExpandSyns
hidden-modules:       Language.Haskell.TH.ExpandSyns.SemigroupCompat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-expand-syns-0.4.9.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-expand-syns-0.4.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/th-expand-syns-0.4.9.0
hs-libraries:         HSth-expand-syns-0.4.9.0-4fdSEazGb6JE84XYYt25ma
depends:
    base-4.15.1.0 containers-0.6.4.1 syb-0.7.2.1-7izZw2FJp8J8g9y09upuDm
    template-haskell-2.17.0.0
    th-abstraction-0.4.3.0-KTsBdnGbxBE1GYg4VOLAou

haddock-interfaces:
    /usr/share/doc/haskell-th-expand-syns/html/th-expand-syns.haddock

haddock-html:         /usr/share/doc/haskell-th-expand-syns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
